package cn.com.qmth.examcloud.core.examwork.dao.entity;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Index;
import javax.persistence.Table;

import org.springframework.format.annotation.DateTimeFormat;

import cn.com.qmth.examcloud.core.examwork.dao.enums.ExamType;
import cn.com.qmth.examcloud.web.jpa.JpaEntity;

/**
 * 考试--特殊设置
 *
 * @author WANGWEI
 * @date 2018年5月16日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
@Entity
@Table(name = "EC_E_EXAM_SPECIAL_SETTINGS", indexes = {
		@Index(name = "IDX_E_E_S_S_001001", columnList = "examId,courseId,orgId", unique = true)})
public class ExamSpecialSettingsEntity extends JpaEntity {

	private static final long serialVersionUID = -3335725218626631530L;

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private Long id;

	/**
	 * 考试ID
	 */
	@Column(nullable = false)
	private Long examId;

	/**
	 * 考试ID
	 */
	@Column(nullable = true)
	private Long courseId;

	/**
	 * 机构ID
	 */
	@Column(nullable = true)
	private Long orgId;

	/**
	 * 顶级机构ID
	 */
	@Column(nullable = false)
	private Long rootOrgId;

	/**
	 * 考试类型
	 */
	@Column(nullable = false)
	@Enumerated(EnumType.STRING)
	private ExamType examType;

	/**
	 * 考试是否可用
	 */
	@Column(nullable = false)
	private Boolean examEnable;

	/**
	 * 考试批次开始时间
	 */
	@DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private Date beginTime;

	/**
	 * 考试批次结束时间
	 */
	@DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private Date endTime;

	/**
	 * 是否禁止考试
	 */
	@Column(nullable = false)
	private Boolean examLimit;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getExamId() {
		return examId;
	}

	public void setExamId(Long examId) {
		this.examId = examId;
	}

	public Long getRootOrgId() {
		return rootOrgId;
	}

	public void setRootOrgId(Long rootOrgId) {
		this.rootOrgId = rootOrgId;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public Date getBeginTime() {
		return beginTime;
	}

	public void setBeginTime(Date beginTime) {
		this.beginTime = beginTime;
	}

	public Date getEndTime() {
		return endTime;
	}

	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}

	public Boolean getExamLimit() {
		return examLimit;
	}

	public void setExamLimit(Boolean examLimit) {
		this.examLimit = examLimit;
	}

	public Long getCourseId() {
		return courseId;
	}

	public void setCourseId(Long courseId) {
		this.courseId = courseId;
	}

	public ExamType getExamType() {
		return examType;
	}

	public void setExamType(ExamType examType) {
		this.examType = examType;
	}

	public Boolean getExamEnable() {
		return examEnable;
	}

	public void setExamEnable(Boolean examEnable) {
		this.examEnable = examEnable;
	}

}
